@@ -243,8 +243,10 @@ def safely_load_json_string(json_string):
 def ensure_valid_project_id(desired_project, data):
     # Confirm they're using either the master key, or their specified project
     # matches with the signed project.
-    if desired_project and str(data.get('project', '')) not in [str(desired_project.pk), desired_project.slug]:
-        raise APIForbidden('Invalid credentials')
+    if desired_project:
+        if str(data.get('project', '')) not in [str(desired_project.pk), desired_project.slug]:
+            raise APIForbidden('Invalid credentials')
+        data['project'] = desired_project.pk
     elif not desired_project:
         data['project'] = 1
 
